import { Buffer } from 'node:buffer';
import { KeyObject, CipherCCM, CipherGCM, DecipherCCM, DecipherGCM } from 'node:crypto';

declare const modes: readonly ["cbc", "ctr", "gcm"];
declare const keySizes: readonly [128, 192, 256];
/**
 * Options for the NanoAES class.
 */
type NanoAESChiperOptions = {
    /**
     * The key to use for encryption/decryption
     */
    key?: Buffer | KeyObject | string;
    /**
     * The mode to use for encryption/decryption. Default: "cbc"
     */
    mode?: typeof modes[number];
    /**
     * The key size to use for encryption/decryption. Default: matches the size of the key
     */
    keySize?: typeof keySizes[number];
};
type AuthenticatedCipher = CipherCCM | CipherGCM;
type AuthenticatedDecipher = DecipherCCM | DecipherGCM;
/**
 * Simple & lightweight AES (Advanced Encryption Standard) module. Wrapper for Node.js crypto module.
 *
 * @param opt - Options for the NanoAES class.
 * @throws If the key is not provided.
 * @throws If the key is not a string or a KeyObject.
 * @throws If the mode is not supported.
 * @throws If the key size is not supported.
 */
declare class NanoAES {
    opt?: NanoAESChiperOptions | undefined;
    private readonly key;
    private readonly algorithm;
    constructor(opt?: NanoAESChiperOptions | undefined);
    /**
     * Encrypts the given data.
     *
     * @param data - The data to encrypt.
     * @returns The encrypted data.
     * @throws If the input is not a Buffer or a string.
     * @throws If encryption fails.
     */
    encrypt(data: Buffer | string): Buffer;
    /**
     * Decrypts the given data.
     *
     * @param encryptedData - The data to decrypt.
     * @returns The decrypted data.
     * @throws If the input is not a Buffer.
     * @throws If the input is not a valid encrypted data.
     * @throws iF the auth tag is not found, but mode is an authenticated mode.
     * @throws If decryption fails.
     */
    decrypt(encryptedData: Buffer): Buffer;
    private isAuthenticated;
    /**
     * Generates a random key.
     *
     * @param size - The size of the key to generate.
     * @returns The generated key.
     */
    static generateKey(size?: NanoAESChiperOptions["keySize"]): KeyObject;
}

export { type AuthenticatedCipher, type AuthenticatedDecipher, NanoAES, type NanoAESChiperOptions };
